@@ -1,14 +1,7 @@
 from abc import ABC
 from dataclasses import dataclass
 from typing import TypeVar
-
-
-class IterableConstants(type):
-    def __iter__(cls):
-        for attr in dir(cls):
-            if not attr.startswith("_") and not callable(getattr(cls, attr)):
-                yield getattr(cls, attr)
-
+from allytools.core.meta import IterableConstants
 
 class EventType:
     def __init__(self, name: str, label: str):
@@ -27,25 +20,20 @@ class EventType:
     def __hash__(self):
         return hash(self.name)
 
-
 class EventTypes(metaclass=IterableConstants):
     ERROR_OCCURRED = EventType("ERROR_OCCURRED", "General error occurred -")
 
-
 @dataclass
 class Event(ABC):
     event_type: EventTypes
     message: str
 
-
 @dataclass
 class LogEvent(Event):
     pass
 
-
 @dataclass
 class ErrorOccurredEvent(Event):
     pass
 
-
-E = TypeVar("E", bound=Event)
+E = TypeVar("E", bound=Event)
\ No newline at end of file
