@@ -1,11 +1,5 @@
-from datetime import datetime
-
 from .BasicEvents import Event, EventType
-
-
-def get_current_timestamp() -> str:
-    return datetime.now().strftime("%Y-%m-%d %H:%M:%S")
-
+from allytools.time.time import get_current_timestamp
 
 class EventLogger:
     def __init__(self, log_vm):
